@@ -17,11 +17,9 @@ public:
     Status status_;
     ProxyExecutor* proxyExecutor_;
 
-    ExecutorDriver();
+    ExecutorDriver(ProxyExecutor* proxyExecutor = (new ProxyExecutor));
     virtual ~ExecutorDriver();
 
-    MesosChannel* get_proxy_channel();
-
     virtual Status start();
     virtual Status stop();
     virtual Status abort();
