@@ -5,9 +5,6 @@
 #include <string>
 #include <vector>
 #include <queue>
-#include <cstdio>
-#include <memory>
-#include <mutex>
 
 #define PUSH_MSG(VEC, MSG, MSG_TYPE) VEC.push_back(CommandArg(MSG.SerializeAsString(), MSG_TYPE))
 
@@ -41,20 +38,11 @@ public:
 class MesosChannel
 {
 public:
-    typedef std::queue<MesosCommand> CommandQueue;
-
-    FILE* in_;
-    FILE* out_;
-    MesosChannel();
-    ~MesosChannel();
-    CommandQueue* pending_;
-    void send(const MesosCommand& command);
-    const MesosCommand recv();
-    MesosChannel* share();
-
-private:
-    int* count_;
-    std::mutex* mutex_;
+    virtual ~MesosChannel(){};
+    virtual void send(const MesosCommand& command) = 0;
+    virtual const MesosCommand recv() = 0;
+    virtual MesosChannel* share() = 0;
+    virtual size_t size() = 0;
 };
 
 } // namespace perl {
